package com.caimei.controller.search;

import com.caimei.controller.user.LoginController;
import com.caimei.entity.*;
import com.caimei.mapper.order.OrderMapper;
import com.caimei.service.search.SearchService;
import com.caimei.utils.AppUtils;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 搜索
 */
@Controller
@RequestMapping("/search")
public class SearchController {
    @Autowired
    private SearchService searchService;
    @Autowired
    private LoginController loginController;
    @Autowired
    private OrderMapper orderMapper;
    @Value("${miniprogram.domain}")
    private String domain;

    /**
     * 首页搜索商品
     */
    @ResponseBody
    @RequestMapping("/product")
    public CmWxJsonModel searchProduct(Integer organizeID, String searchWord, String code, Integer index,
                                       Integer pageSize, HttpServletRequest request) {
        CmWxJsonModel jsonModel = loginController.login(code, request, organizeID);
        String openID = (String) jsonModel.getData();
        //查询历史记录是否存在
        CmMallProductSearchHistory productSearchHistory = searchService.findAllProductRecord(organizeID, searchWord, openID);
        if (productSearchHistory == null) {
            //保存并删除大于10条的历史记录
            searchService.saveProductRecord(organizeID, searchWord, openID);
            searchService.deleteProductRecord(organizeID, openID);
        } else {
            searchService.updateProductRecord(organizeID, searchWord, openID);
        }
        if (index == null) index = 0;
        if (pageSize == null) pageSize = 10;
        PageHelper.startPage(index, pageSize);
        List<CmMallOrganizeProducts> list = searchService.searchProduct(organizeID, searchWord);
        for (CmMallOrganizeProducts products : list) {
            products.setMainImage(AppUtils.getImageURL("product", products.getMainImage(), 0, domain));
            //是否启用阶梯价格
            if (products.getLadderPriceFlag().equals("1")) {
                CmMallProductLadderPrice ladderPrice = searchService.findLadderPrice(products.getId());
                products.setRetailPrice(ladderPrice.getBuyPrice());
            }
        }
        CmMallPage<CmMallOrganizeProducts> productsPage = new CmMallPage<>(list);
        return CmWxJsonModel.newInstance().success(productsPage);
    }

    /**
     * 首页搜索历史记录
     */
    @ResponseBody
    @RequestMapping("/record")
    public CmWxJsonModel productRecord(Integer organizeID, String code, HttpServletRequest request) {
        CmWxJsonModel jsonModel = loginController.login(code, request, organizeID);
        String openID = (String) jsonModel.getData();
        List<CmMallProductSearchHistory> historyList = searchService.findProductRecord(organizeID, openID);
        return CmWxJsonModel.newInstance().success(historyList);
    }

    /**
     * 首页搜索删除历史记录
     */
    @ResponseBody
    @RequestMapping("/delete")
    public CmWxJsonModel deleteProductRecord(Integer organizeID, String code, HttpServletRequest request) {
        CmWxJsonModel model = CmWxJsonModel.newInstance();
        try {
            CmWxJsonModel jsonModel = loginController.login(code, request, organizeID);
            String openID = (String) jsonModel.getData();
            searchService.deleteRecord(organizeID, openID);
        } catch (Exception e) {
            return model.error("删除失败");
        }
        return model.success();
    }

    /**
     * 订单列表搜索订单
     */
    @ResponseBody
    @RequestMapping("/order")
    public CmWxJsonModel searchOrder(Integer organizeID, String searchWord, String code, Integer index,
                                     Integer pageSize, Integer userID, HttpServletRequest request) {
        CmWxJsonModel jsonModel = loginController.login(code, request, organizeID);
        String openID = (String) jsonModel.getData();
        //查询历史记录是否存在
        CmMallProductSearchHistory orderSearchHistory = searchService.findAllOrderRecord(organizeID, searchWord, openID);
        if (orderSearchHistory == null) {
            //保存并删除大于10条的历史记录
            searchService.saveOrderRecord(organizeID, searchWord, openID);
            searchService.deleteOrderRecord(organizeID, openID);
        } else {
            searchService.updateOrderRecord(organizeID, searchWord, openID);
        }
        if (index == null) index = 0;
        if (pageSize == null) pageSize = 10;
        PageHelper.startPage(index, pageSize);
        List<CmMallOrder> orderList = searchService.searchOrder(organizeID, searchWord, userID);
        for (CmMallOrder order : orderList) {
            //111,待付待收待发
            if (order.getStatus().equals(11) && order.getPayStatus().equals("1")) {
                order.setStatus(111);
            }
            String[] ShopOrderIDs = {};
            if (order.getShopOrderIDs().contains(",")) {
                ShopOrderIDs = order.getShopOrderIDs().split(",");
            } else {
                ShopOrderIDs = new String[]{order.getShopOrderIDs()};
            }
            List<CmMallShopOrder> shopOrderList = orderMapper.findAllShopOrder(ShopOrderIDs);
            for (CmMallShopOrder shopOrder : shopOrderList) {
                List<CmMallOrderProduct> orderProductList = orderMapper.findOrderProduct(shopOrder.getShopOrderID());
                for (CmMallOrderProduct orderProduct : orderProductList) {
                    orderProduct.setProductImage(AppUtils.getImageURL("product", orderProduct.getProductImage(), 0, domain));
                }
                shopOrder.setCmOrderProducts(orderProductList);
                shopOrder.setShopLogo(AppUtils.getImageURL("shopLogo", shopOrder.getShopLogo(), 0, domain));
            }
            order.setShopOrderList(shopOrderList);
        }
        CmMallPage<CmMallOrder> orderPage = new CmMallPage<>(orderList);
        return CmWxJsonModel.newInstance().success(orderPage);
    }

    /**
     * 订单搜索历史记录
     */
    @ResponseBody
    @RequestMapping("/history")
    public CmWxJsonModel orderRecord(Integer organizeID, String code, HttpServletRequest request) {
        CmWxJsonModel jsonModel = loginController.login(code, request, organizeID);
        String openID = (String) jsonModel.getData();
        List<CmMallProductSearchHistory> historyList = searchService.findOrderRecord(organizeID, openID);
        return CmWxJsonModel.newInstance().success(historyList);
    }

    /**
     * 订单搜索删除历史记录
     */
    @ResponseBody
    @RequestMapping("/deleteOrderRecord")
    public CmWxJsonModel deleteOrderRecord(Integer organizeID, String code, HttpServletRequest request) {
        CmWxJsonModel model = CmWxJsonModel.newInstance();
        try {
            CmWxJsonModel jsonModel = loginController.login(code, request, organizeID);
            String openID = (String) jsonModel.getData();
            searchService.deleteSearchHistory(organizeID, openID);
        } catch (Exception e) {
            return model.error("删除失败");
        }
        return model.success();
    }
}
