package com.caimei.service.products.impl;

import com.caimei.entity.*;
import com.caimei.mapper.products.DetailsMapper;
import com.caimei.mapper.products.HomePageMapper;
import com.caimei.mapper.products.ShoppingMapper;
import com.caimei.service.products.ShoppingService;
import com.caimei.utils.AppUtils;
import com.github.pagehelper.PageHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class ShoppingServiceImpl implements ShoppingService {
    protected static final Logger logger = LoggerFactory.getLogger(ShoppingServiceImpl.class);
    @Autowired
    private ShoppingMapper shoppingMapper;
    @Autowired
    private HomePageMapper homePageMapper;
    @Autowired
    private DetailsMapper detailsMapper;
    @Value("${miniprogram.domain}")
    private String domain;

    @Override
    public Map<String, Object> findAllCart(Integer userID, Integer index, Integer pageSize) {
        Map<String, Object> map = new HashMap();
        PageHelper.startPage(index, pageSize);
        List<CmMallShop> cmMallShopList = shoppingMapper.findAllShop(userID);
        if (cmMallShopList != null && cmMallShopList.size() > 0) {
            for (CmMallShop cmMallShop : cmMallShopList) {
                List<CmMallOrganizeProducts> productsList = shoppingMapper.findAllProducts(cmMallShop.getShopID(), userID);
                cmMallShop.setProductsList(productsList);
                Double totalPrice = 0d;
                for (CmMallOrganizeProducts products : productsList) {
                    products.setMainImage(AppUtils.getImageURL("product", products.getMainImage(), 0, domain));
                    if (products.getValidFlag().equals("1")) {
                        if (products.getLadderPriceFlag().equals("1")) {
                            //启用阶梯价格
                            List<CmMallProductLadderPrice> ladderPriceList = detailsMapper.findLadderPrice(products.getId());
                            for (CmMallProductLadderPrice ladderPrice : ladderPriceList) {
                                if (products.getProductCount() >= ladderPrice.getBuyNum()) {
                                    products.setRetailPrice(ladderPrice.getBuyPrice());
                                }
                            }
                            products.setProductLadderPrices(ladderPriceList);
                            products.setMinBuyNumber(ladderPriceList.get(0).getBuyNum());
                            products.setRetailPrice(ladderPriceList.get(0).getBuyPrice());
                        }
                        totalPrice += (products.getRetailPrice() * products.getProductCount());
                    }
                }
                cmMallShop.setTotalPrice(totalPrice);
            }
        }
        CmMallPage<CmMallShop> page = new CmMallPage<>(cmMallShopList);
        Integer cartQuantity = homePageMapper.cartQuantity(userID);
        if (cartQuantity == null) cartQuantity = 0;
        logger.info("------------ShoppingServiceImpl.findAllCart.cartQuantity:" + cartQuantity);
        map.put("page", page);
        map.put("cartQuantity", cartQuantity);
        return map;
    }

    @Override
    public void updateNumber(CmMallCart cmMallCart) {
        shoppingMapper.updateNumber(cmMallCart);
    }

    @Override
    public void deleteCart(Integer userID, String productIDs) {
        String[] split = {productIDs};
        if (productIDs.contains(",")) {
            split = productIDs.split(",");
        }
        for (String productID : split) {
            if (productID != null && !productID.equals("")) {
                shoppingMapper.deleteCart(userID, Integer.valueOf(productID));
            }
        }
    }
}
